@@ -70,6 +70,13 @@ sub combine {
     return 1;
 }
 
+sub contains {
+    my ($self, $value) = @_;
+
+    return 1 if $value >= $self->lower && $value <= $self->upper;
+    return 0;
+}
+
 sub divvy {
     my ($self, $n) = @_;
 
@@ -117,6 +124,26 @@ Chart::Clicker::Data::Range implements a range of values.
     upper => 10
   });
 
+=head1 ATTRIBUTES
+
+=head2 lower
+
+Set/Get the lower bound for this Range
+
+=head2 max
+
+Set/Get the maximum value allowed for this Range.  This value should only be
+set if you want to EXPLICITLY set the upper value.
+
+=head2 min
+
+Set/Get the minimum value allowed for this Range.  This value should only be
+set if you want to EXPLICITLY set the lower value.
+
+=head2 upper
+
+Set/Get the upper bound for this Range
+
 =head1 METHODS
 
 =head2 new
@@ -134,6 +161,11 @@ Combine this range with the specified so that this range encompasses the
 values specified.  For example, adding a range with an upper-lower of 1-10
 with one of 5-20 will result in a combined range of 1-20.
 
+=head2 contains ($value)
+
+Returns true if supplied value falls within this range (inclusive).  Otherwise
+returns false.
+
 =head2 divvy
 
   my $values = $range->divvy(5);
@@ -141,28 +173,10 @@ with one of 5-20 will result in a combined range of 1-20.
 Returns an arrayref of $N - 1 values equally spaced in the range so that
 it may be divided into $N pieces.
 
-=head2 lower
-
-Set/Get the lower bound for this Range
-
-=head2 max
-
-Set/Get the maximum value allowed for this Range.  This value should only be
-set if you want to EXPLICITLY set the upper value.
-
-=head2 min
-
-Set/Get the minimum value allowed for this Range.  This value should only be
-set if you want to EXPLICITLY set the lower value.
-
 =head2 span
 
 Returns the span of this range, or UPPER - LOWER.
 
-=head2 upper
-
-Set/Get the upper bound for this Range
-
 =head1 AUTHOR
 
 Cory G Watson <gphat@cpan.org>
